@@ -2,7 +2,7 @@ package PICA::Data;
 use strict;
 use warnings;
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(pica_parser pica_writer pica_path pica_xml_struct
@@ -142,6 +142,7 @@ use PICA::Writer::XML;
 use PICA::Writer::Plus;
 use PICA::Writer::Plain;
 use PICA::Writer::Binary;
+use PICA::Writer::PPXML;
 
 sub pica_parser {
     _pica_module('PICA::Parser', @_)
@@ -167,6 +168,8 @@ sub _pica_module {
         "${base}::Plain"->new(@_);
     } elsif ( $type =~ /^(pica)?xml$/ ) {
         "${base}::XML"->new(@_);
+    } elsif ( $type =~ /^(pica)?ppxml$/ ) {
+        "${base}::PPXML"->new(@_);
     } else {
         croak "unknown PICA parser type: $type";
     }
@@ -434,10 +437,12 @@ record objects:
 
 =head1 CONTRIBUTORS
 
-Johann Rolschewski, C<< <rolschewski@gmail.com> >>
+Johann Rolschewski, C<< <jorol@cpan.org> >>
 
 Jakob Voss C<< <voss@gbv.de> >>
 
+Carsten Klee C<< <klee@cpan.org> >>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2014- Johann Rolschewski and Jakob Voss
